Struct SpawnError

struct SpawnError { ... }

An error that occurred during spawning.

Implementations

impl SpawnError

fn shutdown() -> Self

Spawning failed because the executor has been shut down.

fn is_shutdown(self: &Self) -> bool

Check whether spawning failed to the executor being shut down.

impl Debug for SpawnError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for SpawnError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Error for SpawnError

impl Freeze for SpawnError

impl RefUnwindSafe for SpawnError

impl Send for SpawnError

impl Sync for SpawnError

impl Unpin for SpawnError

impl UnsafeUnpin for SpawnError

impl UnwindSafe for SpawnError

impl<T> Any for SpawnError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SpawnError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SpawnError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for SpawnError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToString for SpawnError

fn to_string(self: &Self) -> String

impl<T, U> Into for SpawnError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SpawnError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SpawnError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>