Trait ArcWake
trait ArcWake: Send + Sync
A way of waking up a specific task.
By implementing this trait, types that are expected to be wrapped in an Arc
can be converted into Waker objects.
Those Wakers can be used to signal executors that a task it owns
is ready to be polled again.
Currently, there are two ways to convert ArcWake into Waker:
Required Methods
fn wake_by_ref(arc_self: &Arc<Self>)Indicates that the associated task is ready to make progress and should be
polled.This function can be called from an arbitrary thread, including threads which did not create the
ArcWakebasedWaker.Executors generally maintain a queue of "ready" tasks;
wake_by_refshould place the associated task onto this queue.This function is similar to
wake, but must not consume the provided data pointer.
Provided Methods
fn wake(self: Arc<Self>)Indicates that the associated task is ready to make progress and should be
polled.This function can be called from an arbitrary thread, including threads which did not create the
ArcWakebasedWaker.Executors generally maintain a queue of "ready" tasks;
wakeshould place the associated task onto this queue.